from rest_framework import serializers
from django.forms.models import model_to_dict
from . import models

class AplicacionSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Aplicacion
        fields = '__all__'

class TipoDispositivoSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.TipoDispositivo
        fields = '__all__'

class TipoParaderoSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.TipoParadero
        fields = '__all__'

class TipoTransporteSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.TipoTransporte
        fields = '__all__'

class TipoVehiculoSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.TipoVehiculo
        fields = '__all__'

class TipoTratamientoPersonaSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.TipoTratamientoPersona
        fields = '__all__'

class PersonaSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Persona
        fields = '__all__'

class UsuarioSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Usuario
        fields = '__all__'
        read_only_fields = ['login']

    def get_fields(self):
        fields = super().get_fields()
        action = self.context['view'].action
        print({ 'action': action })
        if action == 'retrieve' or action == 'list':
            fields = {
                'login': fields['login'],
                'vigente': fields['vigente'],
                'rut': fields['rut'],
            }
        return fields
    
    def to_representation(self, instance):
        representation = super().to_representation(instance)

        # Elimina el campo que deseas después de la actualización
        if 'clave' in representation:
            del representation['clave']

        return representation

class AuthSerializer(serializers.Serializer):
    username = serializers.CharField(required=True)
    password = serializers.CharField(required=True, style={'input_type':'password'})